@@ -110,7 +110,7 @@ property_descriptions = {
 	'syntax': univention.admin.property(
 		short_description=_('Syntax class'),
 		long_description=_("When values are entered, the UMC performs a syntax check. Apart from standard syntax definitions (string) and (integer), there are three possibilities for expressing a binary condition. The syntax TrueFalse is represented at LDAP level using the strings true and false, the syntax TrueFalseUpper corresponds to the OpenLDAP boolean values TRUE and FALSE and the syntax boolean does not save any value or the string 1"),
-		syntax=univention.admin.syntax.string_numbers_letters_dots,
+		syntax=getattr(univention.admin.syntax, "UDM_Syntax", univention.admin.syntax.string_numbers_letters_dots),
 	),
 	'hook': univention.admin.property(
 		short_description=_('Hook class'),
@@ -176,7 +176,7 @@ property_descriptions = {
 	'ldapMapping': univention.admin.property(
 		short_description=_('LDAP attribute'),
 		long_description=_('Univention Corporate Server provides its own LDAP scheme for customer extensions. The LDAP object class univentionFreeAttributes can be used for extended attributes without restrictions. It offers 20 freely usable attributes (univentionFreeAttribute1 to univentionFreeAttribute20) and can be used in connection with any LDAP object (e.g., a user object)'),
-		syntax=univention.admin.syntax.string,
+		syntax=univention.admin.syntax.ldapAttribute,
 		required=True,
 	),
 	'mayChange': univention.admin.property(
@@ -198,7 +198,7 @@ property_descriptions = {
 	'objectClass': univention.admin.property(
 		short_description=_('LDAP object class'),
 		long_description=_('Univention Corporate Server provides its own LDAP scheme for customer extensions. The LDAP object class univentionFreeAttributes can be used for extended attributes without restrictions. It offers 20 freely usable attributes (univentionFreeAttribute1 to univentionFreeAttribute20) and can be used in connection with any LDAP object (e.g., a user object)'),
-		syntax=univention.admin.syntax.string,
+		syntax=univention.admin.syntax.ldapObjectClass,
 		required=True,
 	),
 	'deleteObjectClass': univention.admin.property(
@@ -229,7 +229,7 @@ property_descriptions = {
 	'options': univention.admin.property(
 		short_description=_('Required options'),
 		long_description=_('This extended attribute is only used when at least one of these options is enabled, e.g. "posix" or "samba"'),
-		syntax=univention.admin.syntax.string_numbers_letters_dots,
+		syntax=getattr(univention.admin.syntax, "allModuleOptions", univention.admin.syntax.string_numbers_letters_dots),
 		multivalue=True,
 	),
 	'doNotSearch': univention.admin.property(
